May 12 2012 Rob Story, wrobstory

* Numpy now a requirement for properly parsing Pandas to JSON

May 11 2012 Rob Story, wrobstory

* bearcart.Chart now defaults to auto-axis scaling. Pass "y_zero=True" to set y-axis at 0.
* Explicit type checking for JSON serialization
